@@ -33,8 +33,10 @@ class PHPAutodocDirective(Directive):
         return node.children
 
     def add_entry(self, directive, name, comment):
+        from phply import phpast as ast
+
         if isinstance(comment, ast.Comment):
-            if not self.is_private(last_node):
+            if not self.is_private(comment):
                 self.add_directive_header(directive, name)
                 self.add_comment(comment)
         else:
@@ -75,7 +77,7 @@ class PHPAutodocDirective(Directive):
 
             self._parse(tree)
         except:
-            pass  # FIXME: ignore any errors
+            raise
 
     def _parse(self, tree):
         from phply import phpast as ast
@@ -86,6 +88,7 @@ class PHPAutodocDirective(Directive):
                 self.add_entry('function', node.name, last_node)
             elif isinstance(node, ast.Class):
                 self.add_entry('class', node.name, last_node)
+                self._parse(node.nodes)
             elif isinstance(node, ast.Method):
                 self.add_entry('method', node.name, last_node)
 
